##  Relation Permissions
The Relations section contains permissions for relation fields, grouped in the same order as they appear on the fact sheet page. Each relation field is grouped under its respective relation and has a limited set of configurable permissions. Permissions that aren't applicable to a specific attribute cannot be configured.
